@@ -12,11 +12,10 @@ from PyQt5.Qt import (
     QDesktopServices, QFileDialog, QFileIconProvider, QSettings, QIcon,
     QApplication, QDialog, QUrl, QFont, QFontDatabase, QLocale, QFontInfo)
 
-ORG_NAME = 'KovidsBrain'
-APP_UID  = 'libprs500'
 from calibre import prints
 from calibre.constants import (islinux, iswindows, isbsd, isfrozen, isosx,
-        plugins, config_dir, filesystem_encoding, isxp)
+        plugins, config_dir, filesystem_encoding, isxp, DEBUG, __version__, __appname__ as APP_UID)
+from calibre.ptempfile import base_dir
 from calibre.utils.config import Config, ConfigProxy, dynamic, JSONConfig
 from calibre.ebooks.metadata import MetaInformation
 from calibre.utils.date import UNDEFINED_DATE
@@ -140,12 +139,12 @@ defs['show_vl_tabs'] = False
 defs['show_highlight_toggle_button'] = False
 defs['add_comments_to_email'] = False
 defs['cb_preserve_aspect_ratio'] = False
-defs['show_rating_in_cover_browser'] = True
 defs['gpm_template_editor_font_size'] = 10
 defs['show_emblems'] = False
 defs['emblem_size'] = 32
 defs['emblem_position'] = 'left'
 defs['metadata_diff_mark_rejected'] = False
+defs['tag_browser_show_counts'] = True
 del defs
 # }}}
 
@@ -750,9 +749,11 @@ else:
                 ans = ans[0]
         return ans
 
-    def choose_images(window, name, title, select_only_single_file=True,
-                    formats=('png', 'gif', 'jpg', 'jpeg', 'svg')):
+    def choose_images(window, name, title, select_only_single_file=True, formats=None):
         mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
+        if formats is None:
+            from calibre.gui2.dnd import image_extensions
+            formats = image_extensions()
         fd = FileDialog(title=title, name=name,
                         filters=[(_('Images'), list(formats))],
                         parent=window, add_all_files_filter=False, mode=mode,
@@ -858,6 +859,15 @@ def setup_gui_option_parser(parser):
         parser.add_option('--detach', default=False, action='store_true',
                           help=_('Detach from the controlling terminal, if any (linux only)'))
 
+def show_temp_dir_error(err):
+    import traceback
+    extra = _('Click "Show details" for more information.')
+    if 'CALIBRE_TEMP_DIR' in os.environ:
+        extra = _('The %s environment variable is set. Try unsetting it.') % 'CALIBRE_TEMP_DIR'
+    error_dialog(None, _('Could not create temporary directory'), _(
+        'Could not create temporary directory, calibre cannot start.') + ' ' + extra, det_msg=traceback.format_exc(), show=True)
+
+
 class Application(QApplication):
 
     shutdown_signal_received = pyqtSignal()
@@ -873,8 +883,35 @@ class Application(QApplication):
         self.headless = headless
         qargs = [i.encode('utf-8') if isinstance(i, unicode) else i for i in args]
         self.pi = plugins['progress_indicator'][0]
+        if not isosx and not headless and hasattr(Qt, 'AA_EnableHighDpiScaling'):
+            # On OS X high dpi scaling is turned on automatically by the OS, so we dont need to set it explicitly
+            # This requires Qt >= 5.6
+            for v in ('QT_AUTO_SCREEN_SCALE_FACTOR', 'QT_SCALE_FACTOR', 'QT_SCREEN_SCALE_FACTORS', 'QT_DEVICE_PIXEL_RATIO'):
+                if os.environ.get(v):
+                    break
+            else:
+                # Should probably make a preference to allow the user to
+                # control this, if needed.
+                # Could have options: auto, off, 1.25, 1.5, 1.75, 2, 2.25, 2.5
+                QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
+        QApplication.setOrganizationName('calibre-ebook.com')
+        QApplication.setOrganizationDomain(QApplication.organizationName())
+        QApplication.setApplicationVersion(__version__)
+        QApplication.setApplicationName(APP_UID)
         QApplication.__init__(self, qargs)
         self.setAttribute(Qt.AA_UseHighDpiPixmaps)
+        try:
+            base_dir()
+        except EnvironmentError as err:
+            if not headless:
+                show_temp_dir_error(err)
+            raise SystemExit('Failed to create temporary directory')
+        if DEBUG and not headless:
+            prints('devicePixelRatio:', self.devicePixelRatio())
+            s = self.primaryScreen()
+            if s:
+                prints('logicalDpi:', s.logicalDotsPerInchX(), 'x', s.logicalDotsPerInchY())
+                prints('physicalDpi:', s.physicalDotsPerInchX(), 'x', s.physicalDotsPerInchY())
         if not iswindows:
             self.setup_unix_signals()
         if islinux or isbsd:
