@@ -13,12 +13,12 @@ from datetime import date, datetime
 from PyQt5.Qt import (
     Qt, QDateTimeEdit, pyqtSignal, QMessageBox, QIcon, QToolButton, QWidget,
     QLabel, QGridLayout, QApplication, QDoubleSpinBox, QListWidgetItem, QSize,
-    QPixmap, QDialog, QMenu, QSpinBox, QLineEdit, QSizePolicy, QKeySequence,
+    QPixmap, QDialog, QMenu, QLineEdit, QSizePolicy, QKeySequence,
     QDialogButtonBox, QAction, QCalendarWidget, QDate, QDateTime, QUndoCommand,
     QUndoStack, QVBoxLayout, QPlainTextEdit)
 
 from calibre.gui2.widgets import EnLineEdit, FormatList as _FormatList, ImageView
-from calibre.gui2.widgets2 import access_key, populate_standard_spinbox_context_menu, RightClickButton, Dialog
+from calibre.gui2.widgets2 import access_key, populate_standard_spinbox_context_menu, RightClickButton, Dialog, RatingEditor
 from calibre.utils.icu import sort_key
 from calibre.utils.config import tweaks, prefs
 from calibre.ebooks.metadata import (
@@ -486,10 +486,13 @@ class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
         self.first_time = False
         self.update_state()
 
+    def author_sort_from_authors(self, authors):
+        return self.db.new_api.author_sort_from_authors(authors, key_func=lambda x: x)
+
     def update_state(self, *args):
         au = unicode(self.authors_edit.text())
         au = re.sub(r'\s+et al\.$', '', au)
-        au = self.db.author_sort_from_authors(string_to_authors(au))
+        au = self.author_sort_from_authors(string_to_authors(au))
 
         normal = au == self.current_val
         col = OK_COLOR if normal else ERR_COLOR
@@ -517,7 +520,7 @@ class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
         au = unicode(self.authors_edit.text())
         au = re.sub(r'\s+et al\.$', '', au).strip()
         authors = string_to_authors(au)
-        self.current_val = self.db.author_sort_from_authors(authors)
+        self.current_val = self.author_sort_from_authors(authors)
 
     def author_to_sort(self, *args):
         au = unicode(self.authors_edit.text())
@@ -783,7 +786,7 @@ class FormatsManager(QWidget):
         self.cover_from_format_button = QToolButton(self)
         self.cover_from_format_button.setToolTip(
                 _('Set the cover for the book from the selected format'))
-        self.cover_from_format_button.setIcon(QIcon(I('book.png')))
+        self.cover_from_format_button.setIcon(QIcon(I('default_cover.png')))
         self.cover_from_format_button.setIconSize(QSize(32, 32))
 
         self.metadata_from_format_button = QToolButton(self)
@@ -1071,8 +1074,7 @@ class Cover(ImageView):  # {{{
 
     def select_cover(self, *args):
         files = choose_images(
-            self, 'change cover dialog', _('Choose cover for ') + self.dialog.title.current_val,
-            formats=('png', 'gif', 'jpg', 'jpeg'))
+            self, 'change cover dialog', _('Choose cover for ') + self.dialog.title.current_val)
         if not files:
             return
         _file = files[0]
@@ -1172,6 +1174,7 @@ class Cover(ImageView):  # {{{
                 pm = QPixmap(I('default_cover.png'))
             else:
                 self._cdata = cdata
+            pm.setDevicePixelRatio(getattr(self, 'devicePixelRatioF', self.devicePixelRatio)())
             self.setPixmap(pm)
             tt = _('This book has no cover')
             if self._cdata:
@@ -1231,7 +1234,7 @@ class CommentsEdit(Editor, ToMetadataMixin):  # {{{
             db.set_comment(id_, self.current_val, notify=False, commit=False)
 # }}}
 
-class RatingEdit(make_undoable(QSpinBox), ToMetadataMixin):  # {{{
+class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
     LABEL = _('&Rating:')
     TOOLTIP = _('Rating of this book. 0-5 stars')
     FIELD_NAME = 'rating'
@@ -1240,40 +1243,26 @@ class RatingEdit(make_undoable(QSpinBox), ToMetadataMixin):  # {{{
         super(RatingEdit, self).__init__(parent)
         self.setToolTip(self.TOOLTIP)
         self.setWhatsThis(self.TOOLTIP)
-        self.setMaximum(5)
-        self.setSuffix(' ' + _('stars'))
-        self.setSpecialValueText(_('Not rated'))
 
     @dynamic_property
     def current_val(self):
         def fget(self):
-            return self.value()
+            return self.rating_value
         def fset(self, val):
-            if val is None:
-                val = 0
-            val = int(val)
-            if val < 0:
-                val = 0
-            if val > 5:
-                val = 5
-            self.set_spinbox_value(val)
+            self.rating_value = val
         return property(fget=fget, fset=fset)
 
     def initialize(self, db, id_):
         val = db.rating(id_, index_is_id=True)
-        if val > 0:
-            val = int(val/2.)
-        else:
-            val = 0
         self.current_val = val
         self.original_val = self.current_val
 
     def commit(self, db, id_):
-        db.set_rating(id_, 2*self.current_val, notify=False, commit=False)
+        db.set_rating(id_, self.current_val, notify=False, commit=False)
         return True
 
     def zero(self):
-        self.setValue(0)
+        self.setCurrentIndex(0)
 
 # }}}
 
