@@ -316,6 +316,7 @@ class ManageUserDictionaries(Dialog):
         l.addRow(bb)
         if d.exec_() != d.Accepted:
             return
+        d.loc.update_recently_used()
         word = unicode(w.text())
         lang = (loc.lang_codes or [canonicalize_lang(get_lang())])[0]
         if not word:
@@ -360,7 +361,7 @@ class ManageUserDictionaries(Dialog):
         words = set(filter(None, [x.strip() for x in unicode(w.toPlainText()).splitlines()]))
         lang = lc[0]
         words = {(w, lang) for w in words} - self.current_dictionary.words
-        if dictionaries.add_to_user_dictionary(self.current_dictionary.name, words, None):
+        if dictionaries.add_to_user_dictionary(self.current_dictionary.name, words, DictionaryLocale(lang, None)):
             dictionaries.clear_caches()
             self.show_current_dictionary()
             self.dictionaries_changed = True
@@ -805,6 +806,7 @@ class WordsView(QTableView):
     ignore_all = pyqtSignal()
     add_all = pyqtSignal(object)
     change_to = pyqtSignal(object, object)
+    current_changed = pyqtSignal(object, object)
 
     def __init__(self, parent=None):
         QTableView.__init__(self, parent)
@@ -863,6 +865,9 @@ class WordsView(QTableView):
         if words:
             QApplication.clipboard().setText('\n'.join(words))
 
+    def currentChanged(self, cur, prev):
+        self.current_changed.emit(cur, prev)
+
 class SpellCheck(Dialog):
 
     work_finished = pyqtSignal(object, object, object)
@@ -936,7 +941,7 @@ class SpellCheck(Dialog):
         w.add_all.connect(self.add_all)
         w.activated.connect(self.word_activated)
         w.change_to.connect(self.change_to)
-        w.currentChanged = self.current_word_changed
+        w.current_changed.connect(self.current_word_changed)
         state = tprefs.get(self.state_name, None)
         hh = self.words_view.horizontalHeader()
         h.addWidget(w)
